summaryrefslogtreecommitdiffstats
path: root/lib/libalpm/provide.c
diff options
context:
space:
mode:
authorAaron Griffin <aaron@archlinux.org>2006-10-20 08:26:55 +0200
committerAaron Griffin <aaron@archlinux.org>2006-10-20 08:26:55 +0200
commit7131b7ac87b9793c06d7b7e59df103658dd76ec7 (patch)
treed20bcf43f1d93118577c50977ce34cc6340460e1 /lib/libalpm/provide.c
parente7f886aac3991b6a12ede9781af741b402dffb64 (diff)
downloadpacman-7131b7ac87b9793c06d7b7e59df103658dd76ec7.tar.gz
pacman-7131b7ac87b9793c06d7b7e59df103658dd76ec7.tar.xz
A handful of minor changes:
* Removed the PMList typedef, in favor of the same naming scheme other structs use 'pmlist_t' * Added a time stamp on debug output, to make it more informational * Moved alpm_db_register to _alpm_db_register, making the public function not take a callback parameter
Diffstat (limited to 'lib/libalpm/provide.c')
-rw-r--r--lib/libalpm/provide.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/libalpm/provide.c b/lib/libalpm/provide.c
index bca6b7da..cd5db3e0 100644
--- a/lib/libalpm/provide.c
+++ b/lib/libalpm/provide.c
@@ -28,12 +28,12 @@
#include "db.h"
#include "provide.h"
/* return a PMList of packages in "db" that provide "package"
*/
-PMList *_alpm_db_whatprovides(pmdb_t *db, char *package)
+pmlist_t *_alpm_db_whatprovides(pmdb_t *db, char *package)
{
- PMList *pkgs = NULL;
- PMList *lp;
+ pmlist_t *pkgs = NULL;
+ pmlist_t *lp;
if(db == NULL || package == NULL || strlen(package) == 0) {
return(NULL);
@@ -28,12 +28,12 @@
#include "db.h"
#include "provide.h"
-/* return a PMList of packages in "db" that provide "package"
+/* return a pmlist_t of packages in "db" that provide "package"
*/